@@ -2,9 +2,10 @@
 
    @author Simon Cross <simon.cross@ska.ac.za>
    @modified Jason Manley <jason_manley@hotmail.com>
-   @Revised 2009/12/01 to include print 10gbe core details.
-   @Revised 2010/01/07 to include bulkread
+   @Revised 2010/11/08 to log incomming log informs
    @Revised 2010/06/28 to include qdr stuff
+   @Revised 2010/01/07 to include bulkread
+   @Revised 2009/12/01 to include print 10gbe core details.
    """
 
 import struct, re, threading, socket, select, traceback, logging, sys, time, os
@@ -41,6 +42,11 @@ class FpgaClient(BlockingClient):
         self._timeout = timeout
         self.start(daemon=True)
 
+    def inform_log(self,message):
+        "If we get a log inform, log it."
+        DeviceLogger.log_to_python(self._logger, message)
+        
+
     def _request(self, name, *args):
         """Make a blocking request and check the result.
         
@@ -395,8 +401,12 @@ class FpgaClient(BlockingClient):
             data = struct.pack(">I", integer)
         if blindwrite:
             self.blindwrite(device_name,data,offset*4)
+            self._logger.debug("Blindwrite %8x to register %s at offset %d done."
+                % (integer, device_name, offset))
         else:
             self.write(device_name, data, offset*4)
+            self._logger.debug("Write %8x to register %s at offset %d ok."
+                % (integer, device_name, offset))
 
     def read_uint(self, device_name,offset=0):
         """As in .read_int(), but unpack into 32 bit unsigned int. Optionally read at an offset 32-bit register.
@@ -558,13 +568,11 @@ class FpgaClient(BlockingClient):
         self.write_int(dev_name+'_ctrl',(0 + (man_trig<<1) + (man_valid<<2)))
         self.write_int(dev_name+'_ctrl',(1 + (man_trig<<1) + (man_valid<<2)))
 
-        time.sleep(wait_period)
-
         done=False
         start_time=time.time()
         while not (done and (offset>0 or circular_capture)) and ((time.time()-start_time)<wait_period):
-            addr= self.read_uint(dev_name+'_addr')
-            done=bool(addr & 0x80000000)
+            addr = self.read_uint(dev_name+'_addr')
+            done = bool(addr & 0x80000000)
 
         bram_size= self.read_uint(dev_name+'_addr')&0x7fffffff
         bram_dmp=dict()
